Comprehensive module list
=========================

``sage.combinat``
-----------------

.. toctree::
    :maxdepth: 1

    sage/combinat/bijectionist
    sage/combinat/abstract_tree
    sage/combinat/affine_permutation
    sage/combinat/algebraic_combinatorics
    sage/combinat/alternating_sign_matrix
    sage/combinat/backtrack
    sage/combinat/baxter_permutations
    sage/combinat/expnums
    sage/combinat/binary_recurrence_sequences
    sage/combinat/binary_tree
    sage/combinat/blob_algebra
    sage/combinat/regular_sequence_bounded
    sage/combinat/fast_vector_partitions
    sage/combinat/cartesian_product
    sage/combinat/cluster_complex
    sage/combinat/colored_permutations
    sage/combinat/combination
    sage/combinat/diagram
    sage/combinat/combinat
    sage/combinat/combinatorial_map
    sage/combinat/triangles_FHM
    sage/combinat/all
    sage/combinat/tutorial
    sage/combinat/quickref
    sage/combinat/finite_state_machine_generators
    sage/combinat/composition_tableau
    sage/combinat/constellation
    sage/combinat/core
    sage/combinat/counting
    sage/combinat/integer_matrices
    sage/combinat/cyclic_sieving_phenomenon
    sage/combinat/debruijn_sequence
    sage/combinat/decorated_permutation
    sage/combinat/degree_sequences
    sage/combinat/derangements
    sage/combinat/descent_algebra
    sage/combinat/diagram_algebras
    sage/combinat/dyck_word
    sage/combinat/enumerated_sets
    sage/combinat/dlx
    sage/combinat/family
    sage/combinat/combinat_cython
    sage/combinat/set_partition_iterator
    sage/combinat/finite_state_machine
    sage/combinat/free_dendriform_algebra
    sage/combinat/free_module
    sage/combinat/free_prelie_algebra
    sage/combinat/fqsym
    sage/combinat/fully_commutative_elements
    sage/combinat/fully_packed_loop
    sage/combinat/sloane_functions
    sage/combinat/gelfand_tsetlin_patterns
    sage/combinat/tamari_lattices
    sage/combinat/gray_codes
    sage/combinat/grossman_larson_algebras
    sage/combinat/growth
    sage/combinat/hall_polynomial
    sage/combinat/composition
    sage/combinat/partition
    sage/combinat/integer_vectors_mod_permgroup
    sage/combinat/partitions
    sage/combinat/kazhdan_lusztig
    sage/combinat/key_polynomial
    sage/combinat/partition_kleshchev
    sage/combinat/knutson_tao_puzzles
    sage/combinat/lr_tableau
    sage/combinat/misc
    sage/combinat/necklace
    sage/combinat/non_decreasing_parking_function
    sage/combinat/integer_vector
    sage/combinat/multiset_partition_into_sets_ordered
    sage/combinat/ordered_tree
    sage/combinat/set_partition_ordered
    sage/combinat/output
    sage/combinat/parallelogram_polyomino
    sage/combinat/parking_functions
    sage/combinat/partition_shifting_algebras
    sage/combinat/partition_tuple
    sage/combinat/partition_algebra
    sage/combinat/catalog_partitions
    sage/combinat/graph_path
    sage/combinat/perfect_matching
    sage/combinat/permutation
    sage/combinat/permutation_cython
    sage/combinat/plane_partition
    sage/combinat/ranker
    sage/combinat/recognizable_series
    sage/combinat/symmetric_group_representations
    sage/combinat/tableau_residues
    sage/combinat/restricted_growth
    sage/combinat/ribbon_shaped_tableau
    sage/combinat/ribbon_tableau
    sage/combinat/ribbon
    sage/combinat/rsk
    sage/combinat/rooted_tree
    sage/combinat/schubert_polynomial
    sage/combinat/set_partition
    sage/combinat/shard_order
    sage/combinat/shifted_primed_tableau
    sage/combinat/shuffle
    sage/combinat/sidon_sets
    sage/combinat/composition_signed
    sage/combinat/similarity_class_type
    sage/combinat/six_vertex_model
    sage/combinat/skew_partition
    sage/combinat/skew_tableau
    sage/combinat/specht_module
    sage/combinat/SJT
    sage/combinat/k_tableau
    sage/combinat/subset
    sage/combinat/subsets_hereditary
    sage/combinat/subsets_pairwise
    sage/combinat/e_one_star
    sage/combinat/subword_complex
    sage/combinat/subword_complex_c
    sage/combinat/subword
    sage/combinat/superpartition
    sage/combinat/super_tableau
    sage/combinat/symmetric_group_algebra
    sage/combinat/t_sequences
    sage/combinat/tableau_tuple
    sage/combinat/tableau
    sage/combinat/interval_posets
    sage/combinat/hillman_grassl
    sage/combinat/tiling
    sage/combinat/enumeration_mod_permgroup
    sage/combinat/tools
    sage/combinat/tuple
    sage/combinat/vector_partition
    sage/combinat/integer_vector_weighted
    sage/combinat/yang_baxter_graph
    sage/combinat/nu_dyck_word
    sage/combinat/nu_tamari_lattice
    sage/combinat/regular_sequence
    sage/combinat/q_bernoulli
    sage/combinat/q_analogues
    sage/combinat/sine_gordon

``sage.combinat.chas``
----------------------

.. toctree::
    :maxdepth: 1

    sage/combinat/chas/all
    sage/combinat/chas/fsym
    sage/combinat/chas/wqsym

``sage.combinat.cluster_algebra_quiver``
----------------------------------------

.. toctree::
    :maxdepth: 1

    sage/combinat/cluster_algebra_quiver/all
    sage/combinat/cluster_algebra_quiver/cluster_seed
    sage/combinat/cluster_algebra_quiver/mutation_type
    sage/combinat/cluster_algebra_quiver/interact
    sage/combinat/cluster_algebra_quiver/quiver
    sage/combinat/cluster_algebra_quiver/quiver_mutation_type
    sage/combinat/cluster_algebra_quiver/mutation_class

``sage.combinat.crystals``
--------------------------

.. toctree::
    :maxdepth: 1

    sage/combinat/crystals/affine
    sage/combinat/crystals/affine_factorization
    sage/combinat/crystals/affinization
    sage/combinat/crystals/alcove_path
    sage/combinat/crystals/crystals
    sage/combinat/crystals/bkk_crystals
    sage/combinat/crystals/catalog_infinity_crystals
    sage/combinat/crystals/catalog_kirillov_reshetikhin
    sage/combinat/crystals/catalog
    sage/combinat/crystals/catalog_elementary_crystals
    sage/combinat/crystals/multisegments
    sage/combinat/crystals/mv_polytopes
    sage/combinat/crystals/all
    sage/combinat/crystals/kac_modules
    sage/combinat/crystals/generalized_young_walls
    sage/combinat/crystals/letters
    sage/combinat/crystals/monomial_crystals
    sage/combinat/crystals/direct_sum
    sage/combinat/crystals/elementary_crystals
    sage/combinat/crystals/fast_crystals
    sage/combinat/crystals/fully_commutative_stable_grothendieck
    sage/combinat/crystals/highest_weight_crystals
    sage/combinat/crystals/induced_structure
    sage/combinat/crystals/kirillov_reshetikhin
    sage/combinat/crystals/kyoto_path_model
    sage/combinat/crystals/littelmann_path
    sage/combinat/crystals/pbw_datum
    sage/combinat/crystals/polyhedral_realization
    sage/combinat/crystals/spins
    sage/combinat/crystals/star_crystal
    sage/combinat/crystals/subcrystal
    sage/combinat/crystals/tensor_product_element
    sage/combinat/crystals/tensor_product
    sage/combinat/crystals/virtual_crystal
    sage/combinat/crystals/pbw_crystal
    sage/combinat/crystals/infinity_crystals

``sage.combinat.designs``
-------------------------

.. toctree::
    :maxdepth: 1

    sage/combinat/designs/bibd
    sage/combinat/designs/block_design
    sage/combinat/designs/MOLS_handbook_data
    sage/combinat/designs/design_catalog
    sage/combinat/designs/all
    sage/combinat/designs/covering_array
    sage/combinat/designs/covering_design
    sage/combinat/designs/designs_pyx
    sage/combinat/designs/gen_quadrangles_with_spread
    sage/combinat/designs/database
    sage/combinat/designs/difference_family
    sage/combinat/designs/difference_matrices
    sage/combinat/designs/evenly_distributed_sets
    sage/combinat/designs/ext_rep
    sage/combinat/designs/group_divisible_designs
    sage/combinat/designs/subhypergraph_search
    sage/combinat/designs/incidence_structures
    sage/combinat/designs/latin_squares
    sage/combinat/designs/orthogonal_arrays
    sage/combinat/designs/orthogonal_arrays_build_recursive
    sage/combinat/designs/orthogonal_arrays_find_recursive
    sage/combinat/designs/resolvable_bibd
    sage/combinat/designs/steiner_quadruple_systems
    sage/combinat/designs/twographs

``sage.combinat.integer_lists``
-------------------------------

.. toctree::
    :maxdepth: 1

    sage/combinat/integer_lists/invlex
    sage/combinat/integer_lists/base
    sage/combinat/integer_lists/lists
    sage/combinat/integer_lists/nn

``sage.combinat.matrices``
--------------------------

.. toctree::
    :maxdepth: 1

    sage/combinat/matrices/all
    sage/combinat/matrices/dancing_links
    sage/combinat/matrices/dlxcpp
    sage/combinat/matrices/hadamard_matrix
    sage/combinat/matrices/latin

``sage.combinat.ncsf_qsym``
---------------------------

.. toctree::
    :maxdepth: 1

    sage/combinat/ncsf_qsym/combinatorics
    sage/combinat/ncsf_qsym/generic_basis_code
    sage/combinat/ncsf_qsym/tutorial
    sage/combinat/ncsf_qsym/ncsf
    sage/combinat/ncsf_qsym/all
    sage/combinat/ncsf_qsym/qsym

``sage.combinat.ncsym``
-----------------------

.. toctree::
    :maxdepth: 1

    sage/combinat/ncsym/bases
    sage/combinat/ncsym/dual
    sage/combinat/ncsym/all
    sage/combinat/ncsym/ncsym

``sage.combinat.path_tableaux``
-------------------------------

.. toctree::
    :maxdepth: 1

    sage/combinat/path_tableaux/catalog
    sage/combinat/path_tableaux/dyck_path
    sage/combinat/path_tableaux/frieze
    sage/combinat/path_tableaux/all
    sage/combinat/path_tableaux/path_tableau
    sage/combinat/path_tableaux/semistandard

``sage.combinat.posets``
------------------------

.. toctree::
    :maxdepth: 1

    sage/combinat/posets/bubble_shuffle
    sage/combinat/posets/cartesian_product
    sage/combinat/posets/poset_examples
    sage/combinat/posets/d_complete
    sage/combinat/posets/elements
    sage/combinat/posets/linear_extension_iterator
    sage/combinat/posets/lattices
    sage/combinat/posets/posets
    sage/combinat/posets/forest
    sage/combinat/posets/hasse_diagram
    sage/combinat/posets/hochschild_lattice
    sage/combinat/posets/incidence_algebras
    sage/combinat/posets/linear_extensions
    sage/combinat/posets/mobile
    sage/combinat/posets/moebius_algebra
    sage/combinat/posets/sashes
    sage/combinat/posets/all
    sage/combinat/posets/hasse_cython
    sage/combinat/posets/hasse_cython_flint

``sage.combinat.rigged_configurations``
---------------------------------------

.. toctree::
    :maxdepth: 1

    sage/combinat/rigged_configurations/bij_abstract_class
    sage/combinat/rigged_configurations/bijection
    sage/combinat/rigged_configurations/bij_infinity
    sage/combinat/rigged_configurations/bij_type_A
    sage/combinat/rigged_configurations/bij_type_A2_odd
    sage/combinat/rigged_configurations/bij_type_A2_dual
    sage/combinat/rigged_configurations/bij_type_A2_even
    sage/combinat/rigged_configurations/bij_type_B
    sage/combinat/rigged_configurations/bij_type_C
    sage/combinat/rigged_configurations/bij_type_D_tri
    sage/combinat/rigged_configurations/bij_type_D
    sage/combinat/rigged_configurations/bij_type_D_twisted
    sage/combinat/rigged_configurations/bij_type_E67
    sage/combinat/rigged_configurations/rc_crystal
    sage/combinat/rigged_configurations/kr_tableaux
    sage/combinat/rigged_configurations/kleber_tree
    sage/combinat/rigged_configurations/rigged_configuration_element
    sage/combinat/rigged_configurations/all
    sage/combinat/rigged_configurations/rigged_configurations
    sage/combinat/rigged_configurations/rc_infinity
    sage/combinat/rigged_configurations/rigged_partition
    sage/combinat/rigged_configurations/tensor_product_kr_tableaux
    sage/combinat/rigged_configurations/tensor_product_kr_tableaux_element

``sage.combinat.root_system``
-----------------------------

.. toctree::
    :maxdepth: 1

    sage/combinat/root_system/ambient_space
    sage/combinat/root_system/associahedron
    sage/combinat/root_system/braid_move_calculator
    sage/combinat/root_system/braid_orbit
    sage/combinat/root_system/branching_rules
    sage/combinat/root_system/cartan_matrix
    sage/combinat/root_system/cartan_type
    sage/combinat/root_system/coxeter_group
    sage/combinat/root_system/coxeter_matrix
    sage/combinat/root_system/coxeter_type
    sage/combinat/root_system/dynkin_diagram
    sage/combinat/root_system/extended_affine_weyl_group
    sage/combinat/root_system/reflection_group_complex
    sage/combinat/root_system/reflection_group_real
    sage/combinat/root_system/fundamental_group
    sage/combinat/root_system/root_lattice_realization_algebras
    sage/combinat/root_system/hecke_algebra_representation
    sage/combinat/root_system/integrable_representations
    sage/combinat/root_system/non_symmetric_macdonald_polynomials
    sage/combinat/root_system/pieri_factors
    sage/combinat/root_system/reflection_group_element
    sage/combinat/root_system/reflection_group_c
    sage/combinat/root_system/root_lattice_realizations
    sage/combinat/root_system/root_space
    sage/combinat/root_system/type_A_affine
    sage/combinat/root_system/type_B_affine
    sage/combinat/root_system/type_C_affine
    sage/combinat/root_system/type_D_affine
    sage/combinat/root_system/type_E_affine
    sage/combinat/root_system/type_F_affine
    sage/combinat/root_system/type_G_affine
    sage/combinat/root_system/type_marked
    sage/combinat/root_system/type_affine
    sage/combinat/root_system/type_dual
    sage/combinat/root_system/type_folded
    sage/combinat/root_system/type_reducible
    sage/combinat/root_system/type_relabel
    sage/combinat/root_system/type_super_A
    sage/combinat/root_system/type_A
    sage/combinat/root_system/type_A_infinity
    sage/combinat/root_system/type_B
    sage/combinat/root_system/type_BC_affine
    sage/combinat/root_system/type_C
    sage/combinat/root_system/type_D
    sage/combinat/root_system/type_E
    sage/combinat/root_system/type_F
    sage/combinat/root_system/type_G
    sage/combinat/root_system/type_H
    sage/combinat/root_system/type_I
    sage/combinat/root_system/type_Q
    sage/combinat/root_system/all
    sage/combinat/root_system/root_system
    sage/combinat/root_system/plot
    sage/combinat/root_system/weight_lattice_realizations
    sage/combinat/root_system/weight_space
    sage/combinat/root_system/weyl_characters
    sage/combinat/root_system/weyl_group

``sage.combinat.sf``
--------------------

.. toctree::
    :maxdepth: 1

    sage/combinat/sf/abreu_nigro
    sage/combinat/sf/character
    sage/combinat/sf/classical
    sage/combinat/sf/elementary
    sage/combinat/sf/dual
    sage/combinat/sf/hall_littlewood
    sage/combinat/sf/hecke
    sage/combinat/sf/homogeneous
    sage/combinat/sf/jack
    sage/combinat/sf/kfpoly
    sage/combinat/sf/llt
    sage/combinat/sf/macdonald
    sage/combinat/sf/monomial
    sage/combinat/sf/multiplicative
    sage/combinat/sf/ns_macdonald
    sage/combinat/sf/orthogonal
    sage/combinat/sf/powersum
    sage/combinat/sf/k_dual
    sage/combinat/sf/schur
    sage/combinat/sf/all
    sage/combinat/sf/sfa
    sage/combinat/sf/orthotriang
    sage/combinat/sf/sf
    sage/combinat/sf/symplectic
    sage/combinat/sf/witt
    sage/combinat/sf/new_kschur

``sage.combinat.species``
-------------------------

.. toctree::
    :maxdepth: 1

    sage/combinat/species/characteristic_species
    sage/combinat/species/all
    sage/combinat/species/species
    sage/combinat/species/composition_species
    sage/combinat/species/cycle_species
    sage/combinat/species/empty_species
    sage/combinat/species/library
    sage/combinat/species/functorial_composition_species
    sage/combinat/species/generating_series
    sage/combinat/species/linear_order_species
    sage/combinat/species/misc
    sage/combinat/species/partition_species
    sage/combinat/species/permutation_species
    sage/combinat/species/product_species
    sage/combinat/species/recursive_species
    sage/combinat/species/set_species
    sage/combinat/species/structure
    sage/combinat/species/subset_species
    sage/combinat/species/sum_species

``sage.combinat.words``
-----------------------

.. toctree::
    :maxdepth: 1

    sage/combinat/words/abstract_word
    sage/combinat/words/alphabet
    sage/combinat/words/all
    sage/combinat/words/word_generators
    sage/combinat/words/word_datatypes
    sage/combinat/words/word_infinite_datatypes
    sage/combinat/words/word_char
    sage/combinat/words/finite_word
    sage/combinat/words/infinite_word
    sage/combinat/words/lyndon_word
    sage/combinat/words/morphic
    sage/combinat/words/words
    sage/combinat/words/shuffle_product
    sage/combinat/words/suffix_trees
    sage/combinat/words/word_options
    sage/combinat/words/word
    sage/combinat/words/morphism
    sage/combinat/words/paths


See also
--------

.. toctree::
    :maxdepth: 1

    sage/rings/cfinite_sequence
    sage/rings/lazy_species

.. NOTE::

    This list was initially created by executing in a Sage shell (``sage -sh``)::

    $ src/doc/en/reference/make_module_list.sh sage/combinat

    The result was copy-pasted here, grouped by package.

